SystemOrganization addCategory: #ConfigurationOfKozen!

Object subclass: #ConfigurationOfKozen
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfKozen'!

!ConfigurationOfKozen commentStamp: 'StephaneDucasse 6/27/2012 13:01' prior: 0!
(ConfigurationOfKozen project version: '1.5') load: 'full'
(ConfigurationOfKozen project version: #stable) load: 'full'
(ConfigurationOfKozen project version: #development) load: 'full'

		
	!

!ConfigurationOfKozen class methodsFor: 'as yet unclassified' stamp: ''!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfKozen class methodsFor: 'as yet unclassified' stamp: ''!
compareVersions
	"Compare previous version to development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfKozen class methodsFor: 'as yet unclassified' stamp: ''!
createNewDevelopmentVersion
	"Create a new development version using the #stable version as model."

	"self createNewDevelopmentVersion"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfKozen class methodsFor: 'as yet unclassified' stamp: ''!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfKozen class methodsFor: 'as yet unclassified' stamp: ''!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfKozen class methodsFor: 'as yet unclassified' stamp: ''!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfKozen class methodsFor: 'as yet unclassified' stamp: ''!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfKozen class methodsFor: 'as yet unclassified' stamp: ''!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfKozen class methodsFor: 'as yet unclassified' stamp: ''!
project

	^self new project! !

!ConfigurationOfKozen class methodsFor: 'as yet unclassified' stamp: ''!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: '- fixed a bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfKozen methodsFor: 'baseline' stamp: ''!
baseline100: spec 
	<version: '1.0-baseline'>
	
	spec for: #pharo do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/Kozen'.
		spec package: 'Kozen'.
		spec package: 'KoCizen' with: [spec requires: 'Citezen'].
		
		spec group: 'default' with: #('Kozen'). 
		spec group: 'full' with: #('Kozen' 'KoCizen'). 
		
	spec project: 'Citezen' with: [
			spec className: 'ConfigurationOfCitezen';
			versionString: #stable;
			loads: #('NoWeb' );
			repository: 'http://www.squeaksource.com/Citezen'.
			]
		].
	! !

!ConfigurationOfKozen methodsFor: 'baseline' stamp: ''!
baseline101: spec 
	<version: '1.1-baseline'>
	
	spec for: #pharo do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/Kozen'.
		spec package: 'Kozen'.
		spec package: 'KoCizen' with: [spec requires: 'Citezen'].
		spec package: 'KozStef' with: [spec requires: 'KoCizen'].
		
		spec group: 'default' with: #('Kozen'). 
		spec group: 'full' with: #('Kozen' 'KoCizen' 'KozStef'). 
		
	spec project: 'Citezen' with: [
			spec className: 'ConfigurationOfCitezen';
			versionString: #stable;
			loads: #('NoWeb' );
			repository: 'http://www.squeaksource.com/Citezen'.
			]
		].
	! !

!ConfigurationOfKozen methodsFor: 'baseline' stamp: ''!
baseline102: spec 
	<version: '1.2-baseline'>
	
	spec for: #pharo do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/Kozen'.
		spec package: 'Kozen'.
		spec package: 'KoCizen' with: [spec requires: 'Citezen'].
		spec package: 'KozStef' with: [spec requires: 'KoCizen'].
		spec package: 'KozSimon' with: [spec requires: 'KoCizen'].
				
		spec group: 'default' with: #('Kozen'). 
		spec group: 'full' with: #('Kozen' 'KoCizen' 'KozStef' 'KozSimon'). 
		
	spec project: 'Citezen' with: [
			spec className: 'ConfigurationOfCitezen';
			versionString: #stable;
			loads: #('NoWeb' );
			repository: 'http://www.squeaksource.com/Citezen'.
			]
		].
	! !

!ConfigurationOfKozen methodsFor: 'baseline' stamp: ''!
baseline103: spec 
	<version: '1.3-baseline'>
	
	spec for: #pharo do: [
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemstone.com/ss/Kozen'.
		spec package: 'Kozen'.
		spec package: 'KoCizen' with: [spec requires: 'Citezen'].
		spec package: 'KozStef' with: [spec requires: 'KoCizen'].
		spec package: 'KozSimon' with: [spec requires: 'KoCizen'].
				
		spec group: 'default' with: #('Kozen'). 
		spec group: 'full' with: #('Kozen' 'KoCizen' 'KozStef' 'KozSimon'). 
		
	spec project: 'Citezen' with: [
			spec className: 'ConfigurationOfCitezen';
			versionString: #stable;
			loads: #('NoWeb' );
			repository: 'http://ss3.gemstone.com/ss/citezen'.
			]
		].
	! !

!ConfigurationOfKozen methodsFor: 'baseline' stamp: 'StephaneDucasse 7/29/2012 11:44'!
baseline104: spec 
	<version: '1.4-baseline'>
	
	spec for: #pharo do: [
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemstone.com/ss/Kozen'.
		spec package: 'Kozen'.
		spec package: 'KoCizen' with: [spec requires: 'Citezen'].
		spec package: 'KozStef' with: [spec requires: 'KoCizen'].
		spec package: 'KozSimon' with: [spec requires: 'KoCizen'].
				
		spec group: 'default' with: #('Kozen'). 
		spec group: 'full' with: #('Kozen' 'KoCizen' 'KozStef' 'KozSimon'). 
		
	spec project: 'Citezen' with: [
			spec className: 'ConfigurationOfCitezen';
			versionString: #stable; "but we override it in the version"
			loads: #('NoWeb' );
			repository: 'http://ss3.gemstone.com/ss/citezen'.
			]
		].
	! !

!ConfigurationOfKozen methodsFor: 'symbolic versions' stamp: 'StephaneDucasse 11/1/2012 22:11'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'pharo1.4.x' version: '1.5'.
	spec for: #'pharo2.x' version: '1.6'.
! !

!ConfigurationOfKozen methodsFor: 'utils' stamp: ''!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		"use atomic load on GemStone to resolve some loading issues"
		Smalltalk at: #SystemVersion ifAbsent: [ project loadType: #atomic ]. 
		project ]! !

!ConfigurationOfKozen methodsFor: 'symbolic versions' stamp: 'StephaneDucasse 11/1/2012 22:11'!
stable: spec
	<symbolicVersion: #'stable'>
	spec for: #'pharo1.3.x' version: '1.2'.
	spec for: #'pharo1.4.x' version: '1.5'.
	spec for: #'pharo2.x' version: '1.6'.
! !

!ConfigurationOfKozen methodsFor: 'versions' stamp: ''!
version08: spec
	<version: '0.8' imports: #('1.0-baseline')>
	
	spec for: #'pharo' do: [
		spec description: 'Before Stef site refactorings'.
		spec author: 'StephaneDucasse'.
		spec timestamp: '18/01/2012 17:45'.
		spec 
			package: 'Kozen' with: 'Kozen-sd.21';
			package: 'KoCizen' with: 'KoCizen-sd.4'.].
! !

!ConfigurationOfKozen methodsFor: 'versions' stamp: ''!
version09: spec
	<version: '0.9' imports: #('1.1-baseline')>
	
	spec for: #'pharo' do: [
		spec description: 'Support CSS creation '.
		spec author: 'StephaneDucasse'.
		spec timestamp: '2/02/2012 17:45'.
		spec 
			package: 'Kozen' with: 'Kozen-StephaneDucasse.29';
			package: 'KoCizen' with: 'KoCizen-StephaneDucasse.5';
			package: 'KozStef' with: 'KozStef-StephaneDucasse.6' .].
! !

!ConfigurationOfKozen methodsFor: 'versions' stamp: ''!
version10: spec
	<version: '1.0' imports: #('1.2-baseline')>
	
	spec for: #'pharo' do: [
		spec description: 'Splitting out personal site'.
		spec author: 'StephaneDucasse'.
		spec timestamp: '2/02/2012 17:45'.
		spec 
			package: 'Kozen' with: 'Kozen-StephaneDucasse.30';
			package: 'KoCizen' with: 'KoCizen-StephaneDucasse.5';
			package: 'KozStef' with: 'KozStef-StephaneDucasse.8' ;
			package: 'KozSimon' with: 'KozSimon-StephaneDucasse.2' 
			.].
! !

!ConfigurationOfKozen methodsFor: 'versions' stamp: ''!
version11: spec
	<version: '1.1' imports: #('1.3-baseline')>
	
	spec for: #'pharo' do: [
		spec description: 'Publishing on ss3'.
		spec author: 'StephaneDucasse'.
		spec timestamp: '2/02/2012 17:45'.
		spec 
			package: 'Kozen' with: 'Kozen-StephaneDucasse.32';
			package: 'KoCizen' with: 'KoCizen-StephaneDucasse.6';
			package: 'KozStef' with: 'KozStef-StephaneDucasse.9' ;
			package: 'KozSimon' with: 'KozSimon-StephaneDucasse.2' 
			.].
! !

!ConfigurationOfKozen methodsFor: 'versions' stamp: ''!
version12: spec
	<version: '1.2' imports: #('1.3-baseline')>
	
	spec for: #'pharo' do: [
		spec blessing: #release.
		spec description: 'Honoring hooks (defaultTitle -> title)'.
		spec author: 'StephaneDucasse'.
		spec timestamp: '12/03/2012 21:45'.
		spec 
			package: 'Kozen' with: 'Kozen-StephaneDucasse.32';
			package: 'KoCizen' with: 'KoCizen-StephaneDucasse.6';
			package: 'KozStef' with: 'KozStef-StephaneDucasse.9' ;
			package: 'KozSimon' with: 'KozSimon-StephaneDucasse.2' 
			.].
! !

!ConfigurationOfKozen methodsFor: 'versions' stamp: ''!
version13: spec
	<version: '1.3' imports: #('1.3-baseline')>
	
	spec for: #'pharo' do: [
		spec blessing: #release.
		spec project: 'Citezen' with: #development.
		spec description: 'Honoring hooks (defaultTitle -> title)'.
		spec author: 'StephaneDucasse'.
		spec timestamp: '12/03/2012 21:45'.
		spec 
			package: 'Kozen' with: 'Kozen-StephaneDucasse.32';
			package: 'KoCizen' with: 'KoCizen-StephaneDucasse.6';
			package: 'KozStef' with: 'KozStef-StephaneDucasse.9' ;
			package: 'KozSimon' with: 'KozSimon-StephaneDucasse.2' 
			.].
! !

!ConfigurationOfKozen methodsFor: 'versions' stamp: ''!
version14: spec
	<version: '1.4' imports: #('1.3-baseline')>
	
	spec for: #'pharo' do: [
		spec blessing: #release.
		spec project: 'Citezen' with: #development.
		spec description: 'better integration with reborn'.
		spec author: 'StephaneDucasse'.
		spec timestamp: '12/03/2012 21:45'.
		spec 
			package: 'Kozen' with: 'Kozen-StephaneDucasse.34';
			package: 'KoCizen' with: 'KoCizen-StephaneDucasse.8';
			package: 'KozStef' with: 'KozStef-StephaneDucasse.11' ;
			package: 'KozSimon' with: 'KozSimon-StephaneDucasse.3' 
			.].
! !

!ConfigurationOfKozen methodsFor: 'versions' stamp: 'StephaneDucasse 9/12/2012 18:38'!
version15: spec
	<version: '1.5' imports: #('1.4-baseline')>
	
	spec for: #'pharo' do: [
		spec blessing: #release.
		spec project: 'Citezen' with: #development.
		spec description: 'Better news and index + conference PC declinaison'.
		spec author: 'StephaneDucasse'.
		spec timestamp: '12/09/2012 21:45'.
		spec 
			package: 'Kozen' with: 'Kozen-StephaneDucasse.41';
			package: 'KoCizen' with: 'KoCizen-StephaneDucasse.10';
			package: 'KozStef' with: 'KozStef-StephaneDucasse.17' ;
			package: 'KozSimon' with: 'KozSimon-StephaneDucasse.4'].
! !

!ConfigurationOfKozen methodsFor: 'versions' stamp: 'StephaneDucasse 12/20/2012 09:40'!
version16: spec
	<version: '1.6' imports: #('1.4-baseline')>
	
	spec for: #'pharo' do: [
		spec blessing: #release.
		spec project: 'Citezen' with: #development.
		spec description: 'Adding DR1'.
		spec author: 'StephaneDucasse'.
		spec timestamp: '31/10/2012 21:45'.
		spec 
			package: 'Kozen' with: 'Kozen-StephaneDucasse.43';
			package: 'KoCizen' with: 'KoCizen-StephaneDucasse.10';
			package: 'KozStef' with: 'KozStef-StephaneDucasse.20' ;
			package: 'KozSimon' with: 'KozSimon-StephaneDucasse.4'].
! !
